@@ -16,11 +16,11 @@ def print_gene_warning_or_error(gene: V1GeneMatch):
     Side Effects:
         Prints report to stdout.
     """
-    message = {'query': gene.query}
+    message = {"query": gene.query}
     if gene.warnings:
-        message['warning'] = gene.warnings[0].gene_warning_code
+        message["warning"] = gene.warnings[0].gene_warning_code
     if gene.errors:
-        message['error'] = gene.errors[0].gene_error_code
+        message["error"] = gene.errors[0].gene_error_code
     print(message)
 
 
@@ -38,8 +38,8 @@ def gene_values_by_fields(gene_descriptor: V1GeneDescriptor, fields=List[str]):
         Prints report to stdout.
     """
     all_available_fields = {
-        'gene_id': gene_descriptor.gene_id,
-        'symbol': gene_descriptor.symbol,
+        "gene_id": gene_descriptor.gene_id,
+        "symbol": gene_descriptor.symbol,
     }
     return dict(filter(lambda i: i[0] in fields, all_available_fields.items()))
 
@@ -65,9 +65,9 @@ def print_gene_metadata_by_fields(gene: V1GeneMatch, fields=List[str]):
 
     gene_descriptor = gene.gene
 
-    gene_metadata = {'query': gene.query}
+    gene_metadata = {"query": gene.query}
     if fields is None:
-        gene_metadata['gene'] = gene_descriptor
+        gene_metadata["gene"] = gene_descriptor
     else:
         gene_metadata.update(gene_values_by_fields(gene_descriptor, fields=fields))
     print(gene_metadata)
